@@ -195,7 +195,7 @@ class PGG_diffusion:
     def set_time_stamps(self, time_stamps):
         for (key, val) in time_stamps.iteritems():
             self._G.node[key]['time_stamp'] = val
-            self._time_stamp = max(val, self._simulation_time)
+            self._simulation_time = max(val, self._simulation_time)
 
     def set_seeder(self, seeder):
         self._infected_node = seeder
